@@ -1164,6 +1164,14 @@ class CharacterMatrix(
             if t in self._taxon_sequence_map:
                 yield t
 
+    def __contains__(self, key):
+        if isinstance(key, str):
+            for t in self._taxon_sequence_map:
+                if t.label == key:
+                    return True
+            return False
+        return key in self._taxon_sequence_map
+
     def values(self):
         """
         Iterates values (i.e. sequences) in this matrix.
@@ -1395,7 +1403,7 @@ class CharacterMatrix(
         for taxon in other_matrix._taxon_sequence_map:
             self._taxon_sequence_map[taxon] = self.__class__.character_sequence_type(other_matrix._taxon_sequence_map[taxon])
 
-    def extend_sequences(self, other_matrix):
+    def extend_sequences(self, other_matrix, is_add_new_sequences=False):
         """
         Extends sequences in ``self`` with characters associated with
         corresponding |Taxon| objects in ``other_matrix``.
@@ -1418,7 +1426,11 @@ class CharacterMatrix(
         if other_matrix.taxon_namespace is not self.taxon_namespace:
             raise error.TaxonNamespaceIdentityError(self, other_matrix)
         for taxon in other_matrix._taxon_sequence_map:
-            if taxon in self._taxon_sequence_map:
+            if taxon not in self._taxon_sequence_map:
+                if not is_add_new_sequences:
+                    continue
+                self._taxon_sequence_map[taxon] = self.__class__.character_sequence_type(other_matrix._taxon_sequence_map[taxon])
+            else:
                 self._taxon_sequence_map[taxon].extend(other_matrix._taxon_sequence_map[taxon])
 
     def extend_matrix(self, other_matrix):
@@ -1493,7 +1505,7 @@ class CharacterMatrix(
             List or some other iterable of |Taxon| instances.
         """
         to_keep = set(taxa)
-        for taxon in self._taxon_sequence_map:
+        for taxon in tuple(self._taxon_sequence_map.keys()):
             if taxon not in to_keep:
                 del self._taxon_sequence_map[taxon]
 
